package org.apache.bcel.generic;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.bcel.classfile.AccessFlags;
import org.apache.bcel.classfile.Attribute;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/FieldGenOrMethodGen.class */
public abstract class FieldGenOrMethodGen extends AccessFlags implements NamedAndTyped, Cloneable {

    @Deprecated
    protected String name;

    @Deprecated
    protected Type type;

    @Deprecated
    protected ConstantPoolGen cp;
    private final List<Attribute> attributeList;
    private final List<AnnotationEntryGen> annotationList;

    public abstract String getSignature();

    protected FieldGenOrMethodGen() {
        this.attributeList = new ArrayList();
        this.annotationList = new ArrayList();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public FieldGenOrMethodGen(int accessFlags) {
        super(accessFlags);
        this.attributeList = new ArrayList();
        this.annotationList = new ArrayList();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void addAll(Attribute[] attrs) {
        Collections.addAll(this.attributeList, attrs);
    }

    public void addAnnotationEntry(AnnotationEntryGen ag) {
        this.annotationList.add(ag);
    }

    public void addAttribute(Attribute a) {
        this.attributeList.add(a);
    }

    public Object clone() {
        try {
            return super.clone();
        } catch (CloneNotSupportedException e) {
            throw new Error("Clone Not Supported");
        }
    }

    public AnnotationEntryGen[] getAnnotationEntries() {
        return (AnnotationEntryGen[]) this.annotationList.toArray(AnnotationEntryGen.EMPTY_ARRAY);
    }

    public Attribute[] getAttributes() {
        return (Attribute[]) this.attributeList.toArray(Attribute.EMPTY_ARRAY);
    }

    public ConstantPoolGen getConstantPool() {
        return this.cp;
    }

    @Override // org.apache.bcel.generic.NamedAndTyped
    public String getName() {
        return this.name;
    }

    @Override // org.apache.bcel.generic.NamedAndTyped
    public Type getType() {
        return this.type;
    }

    public void removeAnnotationEntries() {
        this.annotationList.clear();
    }

    public void removeAnnotationEntry(AnnotationEntryGen ag) {
        this.annotationList.remove(ag);
    }

    public void removeAttribute(Attribute a) {
        this.attributeList.remove(a);
    }

    public void removeAttributes() {
        this.attributeList.clear();
    }

    public void setConstantPool(ConstantPoolGen cp) {
        this.cp = cp;
    }

    @Override // org.apache.bcel.generic.NamedAndTyped
    public void setName(String name) {
        this.name = name;
    }

    @Override // org.apache.bcel.generic.NamedAndTyped
    public void setType(Type type) {
        if (type.getType() == 16) {
            throw new IllegalArgumentException("Type can not be " + type);
        }
        this.type = type;
    }
}
